@@ -122,8 +122,11 @@ class GitIssuePublisher(Publisher):
             principle_name = principle.replace('_', ' ').title()
             score_emoji = f"{details['score']} {details['emoji']}"
             comment = details['comment']
+            # Ensure proper Markdown escaping to handle special characters in comments
+            comment = comment.replace('|', '\\|').replace('\n', ' ')
             report.append(f"| {principle_name} | {score_emoji} | {comment} |\n")
 
+
         return '\n'.join(report)
 
     def append_data_to_comment(self, existing_body: str, adherence: Dict[str, Any]) -> str:
